@@ -5,11 +5,11 @@
 #  open source, and has the attribution requirements (GPL Section 7) at
 #  http://statnet.org/attribution
 #
-#  Copyright 2003-2014 Statnet Commons
+#  Copyright 2008-2017 Statnet Commons
 #######################################################################
 
 logLik.stergm<-function(object, add=FALSE, force.reeval=FALSE, eval.loglik=add || force.reeval, control=control.logLik.stergm(), ...){
-  check.control.class()
+  check.control.class("logLik.stergm","logLik.stergm")
   if(object$estimate=="EGMME") stop("Log-likelihood for ",object$estimate," is not meaningful.")
   
   if(!is.null(control$seed))  set.seed(as.integer(control$seed))
